@@ -7,6 +7,7 @@
  */
 
 
+#define IN_LIBXML
 #include "libxml.h"
 #include <stdlib.h>
 #include <string.h>
@@ -519,8 +520,8 @@ attributeDecl(void *ctx, const xmlChar *elem, const xmlChar *fullname,
     }
     if (ctxt->vctxt.valid == 0)
 	ctxt->valid = 0;
-    if (ctxt->validate && ctxt->wellFormed &&
-        ctxt->myDoc && ctxt->myDoc->intSubset)
+    if ((attr != NULL) && (ctxt->validate) && (ctxt->wellFormed) &&
+        (ctxt->myDoc != NULL) && (ctxt->myDoc->intSubset != NULL))
 	ctxt->valid &= xmlValidateAttributeDecl(&ctxt->vctxt, ctxt->myDoc,
 	                                        attr);
     if (prefix != NULL)
@@ -1247,7 +1248,7 @@ startElement(void *ctx, const xmlChar *fullname, const xmlChar **atts)
     }
 
     /*
-     * process all the attributes whose name start with "xml"
+     * process all the attributes whose name start with "xmlns"
      */
     if (atts != NULL) {
         i = 0;
@@ -1255,7 +1256,8 @@ startElement(void *ctx, const xmlChar *fullname, const xmlChar **atts)
 	value = atts[i++];
 	if (!ctxt->html) {
 	    while ((att != NULL) && (value != NULL)) {
-		if ((att[0] == 'x') && (att[1] == 'm') && (att[2] == 'l'))
+		if ((att[0] == 'x') && (att[1] == 'm') && (att[2] == 'l') &&
+		    (att[3] == 'n') && (att[4] == 's'))
 		    attribute(ctxt, att, value);
 
 		att = atts[i++];
@@ -1301,7 +1303,8 @@ startElement(void *ctx, const xmlChar *fullname, const xmlChar **atts)
 	    }
 	} else {
 	    while ((att != NULL) && (value != NULL)) {
-		if ((att[0] != 'x') || (att[1] != 'm') || (att[2] != 'l'))
+		if ((att[0] != 'x') || (att[1] != 'm') || (att[2] != 'l') ||
+		    (att[3] != 'n') || (att[4] != 's'))
 		    attribute(ctxt, att, value);
 
 		/*
@@ -1453,18 +1456,15 @@ characters(void *ctx, const xmlChar *ch, int len)
     if (lastChild == NULL) {
 	/* first node, first time */
 	xmlNodeAddContentLen(ctxt->node, ch, len);
-#ifndef XML_USE_BUFFER_CONTENT
 	if (ctxt->node->children != NULL) {
 	    ctxt->nodelen = len;
 	    ctxt->nodemem = len + 1;
 	}
-#endif
     } else {
 	int coalesceText = (lastChild != NULL) &&
 	    (lastChild->type == XML_TEXT_NODE) &&
 	    (lastChild->name == xmlStringText);
 	if ((coalesceText) && (ctxt->nodemem != 0)) {
-#ifndef XML_USE_BUFFER_CONTENT
 	    /*
 	     * The whole point of maintaining nodelen and nodemem,
 	     * xmlTextConcat is too costly, i.e. compute length,
@@ -1491,9 +1491,6 @@ characters(void *ctx, const xmlChar *ch, int len)
 	    memcpy(&lastChild->content[ctxt->nodelen], ch, len);
 	    ctxt->nodelen += len;
 	    lastChild->content[ctxt->nodelen] = 0;
-#else
-	    xmlTextConcat(lastChild, ch, len);
-#endif
 	} else if (coalesceText) {
 	    xmlTextConcat(lastChild, ch, len);
 	    if (ctxt->node->children != NULL) {
@@ -1504,12 +1501,10 @@ characters(void *ctx, const xmlChar *ch, int len)
 	    /* Mixed content, first time */
 	    lastChild = xmlNewTextLen(ch, len);
 	    xmlAddChild(ctxt->node, lastChild);
-#ifndef XML_USE_BUFFER_CONTENT
 	    if (ctxt->node->children != NULL) {
 		ctxt->nodelen = len;
 		ctxt->nodemem = len + 1;
 	    }
-#endif
 	}
     }
 }
