@@ -1,6 +1,6 @@
 /*************************************************************************
  *
- * $Id: trionan.c,v 1.7 2002/03/27 16:12:21 veillard Exp $
+ * $Id: trionan.c,v 1.8 2002/04/19 15:16:01 breese Exp $
  *
  * Copyright (C) 2001 Bjorn Reese <breese@users.sourceforge.net>
  *
@@ -62,7 +62,7 @@
  *
  ************************************************************************/
 
-static const char rcsid[] = "@(#)$Id: trionan.c,v 1.7 2002/03/27 16:12:21 veillard Exp $";
+static const char rcsid[] = "@(#)$Id: trionan.c,v 1.8 2002/04/19 15:16:01 breese Exp $";
 
 /*************************************************************************
  * Include files
@@ -324,7 +324,7 @@ trio_nan(void)
   if (result == 0.0) {
     
 #if defined(TRIO_COMPILER_SUPPORTS_C99)
-    result = nan(NULL);
+    result = nan("");
 
 #elif defined(NAN) && defined(__STDC_IEC_559__)
     result = (double)NAN;
